@@ -77,6 +77,8 @@ int quota_ctl(envid_t veid, int cmd);
  * @return		0 on success.
  */
 int quota_off(envid_t veid, int force);
-
+int quota_on(envid_t veid, char *private, dq_param *param);
+int quota_set(envid_t veid, char *private, dq_param *param);
+int quota_init(envid_t veid, char *private, dq_param *param);
 void quouta_inc(dq_param *param, int delta);
 #endif
