@@ -83,7 +83,7 @@ static void raw_on(void)
 		logger(0, errno, "Unable to get term attr");
 		return;
 	}
-	s_tios = tios;
+	memcpy(&s_tios, &tios, sizeof(struct termios));
 	cfmakeraw(&tios);
 	if (tcsetattr(0, TCSADRAIN, &tios) == -1) 
 		logger(0, errno, "Unable to set raw mode");
@@ -166,10 +166,10 @@ static void e_loop(int r_in, int w_in,  int r_out, int w_out)
 int do_enter(vps_handler *h, envid_t veid, char *root)
 {
 	int pid, ret, status;
-	int in[2], out[2];
+	int i, in[2], out[2], st[2];
 	struct sigaction act;
 
-	if (pipe(in) < 0 || pipe(out) < 0) {
+	if (pipe(in) < 0 || pipe(out) < 0 || pipe(st) < 0) {
 		logger(0, errno, "Unable to create pipe");
 		return VZ_RESOURCE_ERROR;
 	}
@@ -189,22 +189,28 @@ int do_enter(vps_handler *h, envid_t veid, char *root)
 	} else if (pid == 0) {
 		int master, slave;
 
-		close(in[1]); close(out[0]);
+		close(in[1]); close(out[0]); close(st[0]);
 		if ((ret = vz_chroot(root)))
-			exit(ret);
+			goto err;
 		ret = vz_env_create_ioctl(h, veid, VE_ENTER);
 		if (ret < 0) {
 			if (errno == ESRCH) 
 	                        ret = VZ_VE_NOT_RUNNING;
 			else
 				ret = VZ_ENVCREATE_ERROR;
-			exit(ret);
+			goto err;
+		}
+		if ((ret = pty_alloc(&master, &slave)))
+			goto err;
+		for (i = 0; i < FOPEN_MAX; i++) {
+			if (i != in[0] && i != out[1] &&
+				i != master && i != slave)
+			{
+				close(i);
+			}
 		}
-		if (pty_alloc(&master, &slave))
-			exit(1);
 		child_term = 0;
 		if ((pid = fork()) == 0) {
-			int i;
 			char buf[64];
 			char *term;
 		        char *arg[] = {"bash",  "-i", NULL};
@@ -225,7 +231,7 @@ int do_enter(vps_handler *h, envid_t veid, char *root)
 			}
 			execve("/bin/bash", arg, env);
 			execve("/bin/sh", arg, env);
-			logger(0, errno, "enter: unable to exec bash");
+			logger(0, errno, "enter failed: unable to exec bash");
 			exit(1);
 		} else if (pid < 0) {
 			logger(0, errno, "Unable to fork");
@@ -239,14 +245,25 @@ int do_enter(vps_handler *h, envid_t veid, char *root)
 				break;
 		close(master);
 		exit(0);
+err:
+		write(st[1], &ret, sizeof(ret));
+		exit(ret);
 	}
-	close(in[0]); close(out[1]);
-	raw_on();
-	e_loop(fileno(stdin), in[1], out[0], fileno(stdout));
-	while ((ret = waitpid(pid, &status, 0)) == -1)
+	close(in[0]); close(out[1]); close(st[1]);
+	/* wait for pts allocation */
+	ret = read(st[0], &status, sizeof(status));
+	if (!ret) {
+		fprintf(stdout, "entered into VPS %d\n", veid);
+		raw_on();
+		e_loop(fileno(stdin), in[1], out[0], fileno(stdout));
+	} else {
+		fprintf(stdout, "enter failed\n");
+	}
+	while ((waitpid(pid, &status, 0)) == -1)
 		if (errno != EINTR)
 			break;
-	raw_off();
+	if (!ret)
+		raw_off();
 	close(in[1]); close(out[0]);
 	return 0;
 }
