@@ -84,8 +84,8 @@ vps_handler *vz_open(envid_t veid)
 
         if ((vzfd = open(VZCTLDEV, O_RDWR)) < 0) {
                 logger(0, errno, "Unable to open %s", VZCTLDEV);
-                logger(0, 0, "Please check that Virtuozzo is running and"
-                        " you have sufficient permissions"
+                logger(0, 0, "Please check that vzdev kernel module is loaded"
+                        " and you have sufficient permissions"
                         " to access the file.");
 		return NULL;
         }
@@ -344,7 +344,7 @@ int vz_env_create(vps_handler *h, envid_t veid, vps_res *res,
 			logger(0,0, "Permission denied");
 			break;
 		case VZ_BAD_KERNEL:
-			logger(0, 0, "Invalid kernel, or some Virtuozzo kernel"
+			logger(0, 0, "Invalid kernel, or some kernel"
 				" modules are not loaded");
 			break;
 		case VZ_SET_CAP:
