@@ -170,21 +170,27 @@ char *find_str(list_head_t *head, const char *val)
 	return NULL;
 }
 
-int add_str2list(list_head_t *head, char *val)
+int add_str2list(list_head_t *head, const char *val)
 {
 	char *token;
 	int ret;
+	char *tmp;
 
-	if ((token = strtok(val, "\t ")) == NULL)
+	ret = 0;
+	if ((tmp = strdup(val)) == NULL)
+		return -1;
+	if ((token = strtok(tmp, "\t ")) == NULL) {
+		free(tmp);
 		return 0;
+	}
 	do {
                 if (find_str(head, token))
 			continue;
 		if ((ret = add_str_param(head, token)))
-			return ret;
+			break;
 	} while ((token = strtok(NULL, "\t ")));
-
-	return 0;
+	free(tmp);
+	return ret;
 }
 
 int merge_str_list(int delall, list_head_t *old, list_head_t *add,
