@@ -46,7 +46,7 @@ void logger(int log_level, int err_no, const char *format, ...)
 	else
 		out = stdout;
 	va_start(ap, format);
-	if (!g_log.quiet && g_log.level >= log_level && !g_log.quiet) {
+	if (!g_log.quiet && g_log.level >= log_level) {
 		vfprintf(out, format, ap);
 		if (err_no)
 			fprintf(out, ": %s", strerror(err_no));
